import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import java.sql.*;
import java.text.*;
import java.util.*;


//
// BookHome Class:  Servlet which displays a book's
// home page given an ISBN in the database.  Redirects
// user to an error page if any errors occurr.
//

public class BookHome extends HttpServlet {

	// Initialize the servlet
	public void init(ServletConfig config) throws ServletException {
		super.init(config);
	}


	// Set local path
	public static String getLocalPath() {

		// ****Change this variable to match the location of your
		// BookShop files on your server.  For example,
		// if your files were located in the directory:
		//
		//     http://server.com/bookshop/
		//
		// then you would set the variable as follows:
		String BookShopHomeLocation = "/bookshop";

		return(BookShopHomeLocation);
	}


	//
	// isNumericString() returns true iff the string input
	// supplied is a long number
	//
	public static boolean isNumericString(String input) {
		// We make sure to catch exceptions in the case
		// that the string is not a long number
		try {
			Long.parseLong(input);
			return(true);
		} catch (NumberFormatException e) {
			return(false);
		}
	}



	// Main Servlet Function:  When someone requests this
	// servlet, output from this function will be directed
	// to user.
	public void doGet (HttpServletRequest request, HttpServletResponse response)
		throws ServletException, IOException, java.net.MalformedURLException {

		// Set the local path for the BookShop
		String BookShopHomeLocation = getLocalPath();

		try {
			// The servlet returns HTML
			response.setContentType("text/html; charset=UTF-8");    
			
			// Output goes in the response stream.
			PrintWriter out = response.getWriter();
		    

			// Part 1: Parse the ISBN and determine whether or not is
			// a valid ISBN was provided
			String ISBN = "", title = "", author = "", availability = "";
			double price = -1;
			long year_published = -1, qty_in_stock = -1;
	
			// First, we retrieve the ISBN from the URL string
			String URL = request.getQueryString();
			if(URL==null)
				URL = "";

			int point=-1;	
			point = URL.lastIndexOf("ISBN=");
			if(point!=-1)
				ISBN = URL.substring(point+5,URL.length());


			// Part 2A - If no ISBN Provided, the ISBN malformed, or
			// it does not represent a valid long number, we display
			// an error
			if(URL==null || point==-1 || !isNumericString(ISBN))
				out.println("<META HTTP-EQUIV=\"Refresh\" CONTENT=\"0; URL="+BookShopHomeLocation+"/invalidbook.html\">");

			// Part 2B - Else, we check to see if the ISBN
			// matches a book in the database
			else {
				boolean Exists = false;
 	
				Class.forName("COM.ibm.db2.jdbc.app.DB2Driver");
				try {
					Connection con = DriverManager.getConnection("jdbc:db2:bookshop","user","pass");
					Statement stmt = con.createStatement();
					String sql = "SELECT title, author, qty_in_stock, price, year_published FROM Books WHERE ISBN = '" + ISBN +"'";
					ResultSet rs = stmt.executeQuery(sql);
					while(rs.next()) {

						// If a book is found, we retrieve its information
						Exists = true;
						title = rs.getString("title");
						author = rs.getString("author");
						qty_in_stock = rs.getLong("qty_in_stock");
						price = rs.getDouble("price");
						year_published = rs.getLong("year_published");

						// Set the availability value based on the
						// number of books in stock
						if(qty_in_stock<0)
							availability = "Usually ships within 4 weeks";
						else if(qty_in_stock<5)
							availability = "Usually ships within 1 week";
						else if(qty_in_stock<20)
							availability = "Usually ships within 2 to 3 days";
						else
							availability = "Usually ships within 1 to 2 days";
		  			}

					// We always close our database connection instances
					rs.close();
					stmt.close();
					con.close();
				}
				catch(Exception e) {
					out.println(e.toString());
				}
		

				// Part 3A - If the ISBN does not match a book in
				// our database, we display an error
				if(!Exists)
					out.println("<META HTTP-EQUIV=\"Refresh\" CONTENT=\"0; URL="+BookShopHomeLocation+"/invalidbook.html\">");
	
				// Part 3B - ISBN does exist so create a proper book
				// information page
				else {

					// Display the HTML page header
					NumberFormat n = NumberFormat.getCurrencyInstance(Locale.US);
					out.println("<HTML>");
					out.println("<TITLE>The Internet BookShop: "+title+"</TITLE>");
					out.println("<script language=\"javascript\" src=\""+BookShopHomeLocation+"/menu.js\"></script>");
					out.println("<BODY>");

					// Display the Book Information
					out.println("<FORM NAME=BuyBook ACTION="+BookShopHomeLocation+"/buybook.jsp METHOD=POST>");
					out.println("<INPUT TYPE=\"HIDDEN\" NAME=\"ISBN\" VALUE=\""+ISBN+"\">");
					out.println(" <TABLE BORDER=\"0\" CELLPADDING=\"0\" CELLSPACING=\"0\" WIDTH=\"100%\" ALIGN=\"CENTER\">");
					out.println("  <TR>");
					out.println("	<TD ALIGN=\"CENTER\" WIDTH=\"100%\">");
					out.println("	<u><FONT size=\"6\"><B>"+title+"</B></FONT></u></TD>");
					out.println("  </TR>");
					out.println("  <TR><TD>&nbsp;</TD></TR>");
					out.println("  <TR><TD align=\"CENTER\" WIDTH=\"100%\" height=\"21\"><i>By:&nbsp; "+author+"</i></TD></TR>");
					out.println("  <TR><TD>&nbsp;</TD></TR>");
					out.println("  <TR><TD>&nbsp;</TD></TR>");
					out.println("  <TR><TD WIDTH=\"100%\">&nbsp;</TD></TR>");
					out.println("  <TR>");
					out.println("    <TD>");
					out.println("    <TABLE BORDER=\"0\" WIDTH=\"52%\" CELLPADDING=\"1\" CELLSPACING=\"1\" align=\"CENTER\">");
					out.println("      <TR>");
					out.println("        <TD WIDTH=\"100%\">");
					out.println("        <TABLE BORDER=\"0\" WIDTH=\"100%\" CELLPADDING=\"1\" CELLSPACING=\"1\" align=\"CENTER\">");
					out.println("          <TR><TD>Publishing Data: "+year_published+"</TD></TR>");
					out.println("          <TR><TD WIDTH=\"100%\">ISBN: "+ISBN+"</TD></TR>");
					out.println("          <TR><TD>&nbsp;</TD></TR>");
					out.println("          <TR><TD><B>Our Price:</B> "+n.format(price)+"</TD></TR>");
					out.println("          <TR><TD><B>Availability:</B> "+availability+"</TD></TR>");
					out.println("        </TABLE>");
					out.println("        </TD>");
					out.println("        <TD WIDTH=\"1%\"><IMG SRC=\""+BookShopHomeLocation+"/images/book2.jpg\"</TD>");
					out.println("      </TR>");
					out.println("      <TR>");
					out.println("        <TD></TD>");
					out.println("        <TD><INPUT TYPE=\"submit\" VALUE=\"Add to Cart\"></TD>");
					out.println("      </TR>");
					out.println("    </TABLE>");
					out.println("    </TD>");
					out.println("  </TR>");
					out.println(" </TABLE><BR/><BR/>");
					out.println("</FORM>");

					// Display the HTML page tail
					out.println("</BODY>");
					out.println("<script language=\"javascript\" src=\""+BookShopHomeLocation+"/footer.js\"></script>");
					out.println("</HTML>");
				}
			}
		} catch (Exception e) {
			PrintWriter out = response.getWriter();
			out.println(e.toString());
		}
	}
} // BookHome